Urban Dictionary: xterm
Description: Godly creature, omnipotent, guru in every way imaginable.

Top Definition
xterm
Godly creature, omnipotent, guru in every way imaginable.
I wish i was an xterm
by Anonymous August 26, 2003
Buy the mug Buy the tshirt

### The Urban Dictionary Mug

Lotsa space for your liquids.

Buy the mug

### The Urban Dictionary Mug

Lotsa space for your liquids.

Buy the mug

### The Urban Dictionary Mug

Your favorite word on a white mug.

Create a mug

### The Urban Dictionary Mug

One side has the word, one side has the definition. Microwave and dishwasher safe. Lotsa space for your liquids.

Buy the mug

### The Urban Dictionary T-Shirt

Soft and offensive. Just like you.

Buy the t-shirt

### The Urban Dictionary T-Shirt

Smooth, soft, slim fit American Apparel shirt. Custom printed. 100% fine jersey cotton, except for heather grey (90% cotton).

Buy the t-shirt
Add your own
Random Word

####
Alphabetical List

- xterm
- Xtermin8er
- Xternah
- Xterra
- x-terra wave
- xtf
- xtg
- x tha fool out da box
- xthree
- X-ti
- xtian
- Xtianity
- xtimbobx
- xTimes
- xtina
- xtina'd
- x-tina kim
- xtina's boobs
- XTINAT
- X-Tinc
- Xtine
- xtine altizer
- xting
- XTL
- xTLA
- Xtlm
- XTM
- xtna
- x to c
- xton
- Xtoner
- x to the D
- X to the O
- X to the Z
- X to the Zizzle
- x-tourette's syndrome
- Xtr8
- xtra
- Xtra Bass
- xtracited

© 1999-2016 Urban Dictionary ®
jobs terms of service privacy
dmca remove help